from django import template
from django.core.paginator import Paginator

register = template.Library()

@register.inclusion_tag('jsim/jsim.html')
def jsim():
    return {}

# @register.simple_tag(takes_context=True)
# def eget(context, show, shell, callback='', callback_error=''):
    # lst = show.split(maxsplit=1)
# 
    # url = '{% url ' + "'%s' " % lst[0] + lst[1] + ' %}'
# 
    # tmp = """
    # data-show="%s"
    # data-shell="%s" 
    # data-callback="%s" data-callback-error="%s"
    # """ % (url, '#%s' % shell, callback, callback_error)
# 
    # tmp = template.Template(tmp)
    # return tmp.render(context)
# 
# @register.simple_tag(takes_context=True)
# def epost(context, show, shell, form='', callback='', callback_error=''):
    # lst = show.split(maxsplit=1)
# 
    # url = '{% url ' + "'%s' " % lst[0] + lst[1] + ' %}'
# 
    # tmp = """
    # data-show="%s"
    # data-shell="%s" 
    # data-form="%s"
    # data-callback="%s" data-callback-error="%s"
    # """ % (url, '#%s' % shell, callback, callback_error, form)
# 
    # tmp = template.Template(tmp)
    # return tmp.render(context)
# 
# 
# 





#! /usr/bin/env python3

from distutils.core import setup

setup(name="django-jsim",
      version="1.0.0",
      description="",
      packages=["jsim", "jsim.templatetags", 
      "jsim.templates", "jsim.static", "jsim.templates.jsim"],
      package_data={'jsim.templates.jsim': ['jsim.html'], 
      'jsim.static':['jsim.js']},

      author="Iury O. G. Figueiredo",
      author_email="ioliveira@id.uff.br",
      url='',
      download_url='',
      keywords=[],
      classifiers=[])





































































